#ifndef EDITOROBJ_H
#define EDITOROBJ_H

#include "obj.h"
#include <gtk/gtk.h>

/*
 *	Editor object structure:
 */
typedef struct {

	/* Basics. */
	gint	type;		/* One of SAR_OBJ_TYPE_*. */
	gulong	flags;		/* Any of SAR_OBJ_FLAG_*. */
	sar_position_struct		pos;	/* Meters. */
	sar_direction_struct		dir;	/* Radians. */
	sar_contact_bounds_struct	cb;
	gfloat	range,				/* Meters. */
		range_far;
	gchar	*name;
	gchar	*description;
	gchar	*model_file;

	/* Reference object. */
	gchar	*ref_obj_name;
	gint	ref_obj_num;
        sar_position_struct	ref_offset;	/* Relative to ref obj in meters. */
        sar_direction_struct	ref_dir;	/* Relative to ref obj in radians. */

	/* Helipad. */
	gulong	helipad_flags;		/* Any of SAR_HELIPAD_FLAG_*. */
	gchar	*helipad_type_name;
	gfloat	helipad_length,		/* Meters. */
		helipad_width;
	gfloat	helipad_recession;	/* Meters. */
	gchar	*helipad_label;

	/* Runway. */
	gulong	runway_flags;		/* Any of SAR_RUNWAY_FLAG_*. */
	gfloat	runway_length,		/* Meters. */
		runway_width;		/* Meters. */
	gint	runway_surface;		/* One of SAR_RUNWAY_SURFACE_*. */
	gint	runway_dashes;
	gfloat	runway_edge_light_spacing;
	gchar	*runway_north_label,
		*runway_south_label;
	gfloat	runway_north_displaced_threshold,
		runway_south_displaced_threshold;
	gulong	runway_north_lighting_flags,
		runway_south_lighting_flags;

	/* Human. */
	gulong	human_flags;		/* Any of SAR_HUMAN_FLAG_*. */
	gchar	*human_type_name;
	gchar	*human_message_enter;

	/* Fire. */
	gfloat	fire_radius,		/* Meters. */
		fire_height;

	/* Smoke. */
	sar_position_struct smoke_offset;	/* Meters. */
	gfloat	smoke_radius_start,		/* Meters. */
		smoke_radius_max;
	gfloat	smoke_radius_rate;		/* -1.0 or meters per cycle. */
	gboolean	smoke_hide_at_max;
	gulong	smoke_respawn_int;		/* Milliseconds. */
	gint	smoke_total_units;
	gint	smoke_color_code;		/* 0 = light grey/white
						 * 1 = medium grey
						 * 2 = dark/black
						 */

	/* Premodeled. */
	gchar	*premodeled_type_name;
	gchar	*premodeled_value;		/* Space separated list of values. */

} editor_obj_struct;

#define EDITOR_OBJ(p)	((editor_obj_struct *)(p))


extern editor_obj_struct *EditorObjNew(void);
extern editor_obj_struct *EditorObjNewWithValues(
	gint type,
	const sar_position_struct *pos,
	const sar_direction_struct *dir,
	const sar_contact_bounds_struct *cb,
	const gchar *name,
	const gchar *model_file
);
extern editor_obj_struct *EditorObjDup(const editor_obj_struct *o);
extern void EditorObjDelete(editor_obj_struct *o);



#endif	/* EDITOROBJ_H */
